@@ -359,7 +359,7 @@ x11SetSmClientId ::
     -> m ()
 x11SetSmClientId smClientId = liftIO $ do
     maybeSmClientId <- case smClientId of
-        Nothing -> return nullPtr
+        Nothing -> return FP.nullPtr
         Just jSmClientId -> do
             jSmClientId' <- textToCString jSmClientId
             return jSmClientId'
